@@ -1,5 +1,7 @@
 from mozilla_django_oidc.auth import OIDCAuthenticationBackend
 
+from .signals import post_login
+
 
 class PiratesOIDCAuthenticationBackend(OIDCAuthenticationBackend):
     """
@@ -23,13 +25,25 @@ class PiratesOIDCAuthenticationBackend(OIDCAuthenticationBackend):
         first_name = claims.get("given_name", "")
         last_name = claims.get("family_name", "")
         email = claims.get("email", "")
-        return self.UserModel.objects.create(
+        user = self.UserModel.objects.create(
             sso_id=sso_id, first_name=first_name, last_name=last_name, email=email
         )
+        self.send_post_login_signal(user, True, claims)
+        return user
 
     def update_user(self, user, claims):
         user.first_name = claims.get("given_name", "")
         user.last_name = claims.get("family_name", "")
         user.email = claims.get("email", "")
         user.save()
+        self.send_post_login_signal(user, False, claims)
         return user
+
+    def send_post_login_signal(self, user, created, claims):
+        post_login.send(
+            sender=self.__class__,
+            user=user,
+            created=created,
+            claims=claims,
+            request=self.request,
+        )
